@@ -8,8 +8,8 @@ module Hakyll.Core.Runtime.Tests
 --------------------------------------------------------------------------------
 import qualified Data.ByteString     as B
 import           System.FilePath     ((</>))
-import           Test.Framework      (Test, testGroup)
-import           Test.HUnit          (Assertion, (@?=))
+import           Test.Tasty          (TestTree, testGroup)
+import           Test.Tasty.HUnit    (Assertion, (@?=))
 
 
 --------------------------------------------------------------------------------
@@ -20,7 +20,7 @@ import           TestSuite.Util
 
 
 --------------------------------------------------------------------------------
-tests :: Test
+tests :: TestTree
 tests = testGroup "Hakyll.Core.Runtime.Tests" $
     fromAssertions "run" [case01, case02]
 
@@ -41,6 +41,15 @@ case01 = do
                     >>= saveSnapshot "raw"
                     >>= renderPandoc
 
+        match (fromList ["partial.html", "partial-helper.html"]) $
+            compile templateCompiler
+        create ["partial.html.out"] $ do
+            route idRoute
+            compile $ do
+                example <- loadSnapshotBody "example.md" "raw"
+                makeItem example
+                    >>= loadAndApplyTemplate "partial.html" defaultContext
+
         create ["bodies.txt"] $ do
             route idRoute
             compile $ do
@@ -60,6 +69,10 @@ case01 = do
     bodies <- readFile $ destinationDirectory testConfiguration </> "bodies.txt"
     head (lines bodies) @?=  "This is an example."
 
+    partial  <- readFile $ providerDirectory    testConfiguration </> "partial.html.out"
+    partial' <- readFile $ destinationDirectory testConfiguration </> "partial.html.out"
+    partial @?= partial'
+
     cleanTestEnv
 
 
